# 2010 August 30 by Joshua R. Davis

# These modules are needed for both 2D and 3D.
from utility import *
from texture import *
from mesh import *
from animation import *
from window import *
# These modules are needed for 2D.
from body2d import *
from renderer2d import *
# These modules are needed for 3D.
from body3d import *
from renderer3d import *
from camera import *

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = Window()
	# Make a white texture to act as a placeholder where no texture is desired.
	whiteTexture = makeWhiteTexture()
	# Attach a 2D renderer that draws shapes with a uniform RGBA color.
	renderer = Renderer2D()
	renderer.setColorCode("u0")
	window.setRenderer2D(renderer)
	# Make a translucent red disk overlay.
	data = diskMeshData(128.0, 64)
	mesh = Mesh(data[0], [data[1]])
	body = Body2D(mesh, [], [(1.0, 0.0, 0.0, 0.75)])
	body.setPosition((200.0, 200.0))
	renderer.getBodies().append(body)
	# Attach a 3D renderer that draws solids with a uniform RGBA color.
	renderer = Renderer3D()
	renderer.setDiffuseCode("u0")
	renderer.setNormalCode("normalize(v0)")
	renderer.setVaryingCodesSizes(["normalize((modelingMatrix * vec4(a1, 0.0)).xyz)"], [3])
	#renderer.setIsSpecular(True)
	window.setRenderer3D(renderer)
	# Attach a perspective camera and a light.
	renderer.setCamera(Camera())
	light = SpotLight(512)
	renderer.setLights((light,))
	# Make a 3D body.
	data = boxMeshData(0.618, 1.0, 1.618)
	mesh = Mesh(data[0], [data[1], data[3]])
	body = Body3D(mesh, [], [(0.25, 0.25, 0.75, 1.0)])
	body.getBody().setPosition((0.0, 0.0, -1.0))
	body.rotate(3.14159265 / 4.0, (1.0, 0.0, 0.0))
	body.rotate(3.14159265 / 3.0, (0.0, 1.0, 0.0))
	renderer.getBodies().append(body)
	# All Bopagopa programs end by telling the window to run the user interface.
	beginUserInterface()
