# 2010 September 3 by Joshua R. Davis

"""
This program is meant to be executed from within the same directory as the Bopagopa Python files. It causes these files to be compiled for the current version of Python. (Compiled Python files are platform-independent but not version-independent.) Once the directory of Bopagopa files contains the compiled files, the directory can be placed anywhere on the Python path. (On my own Mac OS X machine, I put it in /Library/Python/2.6/site-packages.) Programs written by the user can then load Bopagopa or Bopagopa Jr. from anywhere, by doing 'import bopagopa.bopagopa' or 'import bopagopa.bopagopajr'; see the tutorials for examples.

In its functionality this program is identical to the demo section of bopagopajr.py. It makes some 2D shapes and 3D solids. The user can drag them around with the mouse. The keypad controls the camera. The W and F keys control wireframe and fullscreen modes.
"""

import bopagopajr as jr

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = jr.WindowJr()
	# Make some 2D overlays.
	disk = jr.makeDisk(64.0)
	disk.setColor((1.0, 0.0, 0.0, 1.0))
	disk.setPosition((100.0, 200.0))
	window.appendBody2D(disk)
	rectangle = jr.makeRectangle(90.0, 70.0)
	rectangle.setColor((0.3, 0.8, 0.8, 0.7))
	rectangle.setPosition((300.0, 100.0))
	window.appendBody2D(rectangle)
	text = jr.makeText("Bopagopa Jr.", "/Library/Fonts/Silom.ttf", 18)
	text.setColor((1.0, 1.0, 1.0, 1.0))
	text.setPosition((128.0, 16.0))
	window.appendBody2D(text)
	# Make some 3D bodies.
	sphere = jr.makeSphere(1.0)
	sphere.setColor((1.0, 1.0, 0.0))
	window.appendBody3D(sphere)
	cylinder = jr.makeCylinder(1.0, 0.5)
	cylinder.setColor((0.0, 0.0, 1.0))
	cylinder.getBody().setPosition((1.0, 0.0, 1.0))
	window.appendBody3D(cylinder)
	capsule = jr.makeCapsule(1.0, 0.5)
	capsule.setColor((1.0, 0.0, 1.0))
	capsule.getBody().setPosition((0.0, 1.0, 1.0))
	window.appendBody3D(capsule)
	box = jr.makeBox(10.0, 10.0, 1.0)
	box.setColor((0.0, 1.0, 0.0))
	box.getBody().setPosition((0.0, 0.0, -1.0))
	window.appendBody3D(box)
	cone = jr.makeCone(1.0, 0.5)
	cone.setColor((1.0, 0.5, 0.0))
	cone.getBody().setPosition((1.0, 1.0, 1.0))
	window.appendBody3D(cone)
	# Make some lights.
	light = jr.SpotLight(512)
	window.setLights((light,))
	# All Bopagopa programs end by telling the window to run the user interface.
	jr.beginUserInterface()
