# 2010 September 16 by Joshua R. Davis

"""
This program demonstrates the several kinds of shapes available. It also demonstrates scaling and rotating. Some of the shapes are pegged to the right or top sides of the window. This pegging feature can be useful in constructing user interfaces.
"""

import bopagopa.bopagopajr as jr
import math

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = jr.WindowJr()
	# Make a red disk, scaled by 1.3 in the horizontal direction.
	disk = jr.makeDisk(32.0)
	disk.setColor((1.0, 0.0, 0.0, 0.9))
	disk.setPosition((448.0, 256.0))
	disk.setScales((1.3, 1.0))
	window.appendBody2D(disk)
	# Make a yellow sector, pegged to the top right corner of the window.
	sector = jr.makeSector(48.0, 0.0, (2.0 / 3.0) * math.pi)
	sector.setColor((1.0, 1.0, 0.0, 0.9))
	sector.setPosition((352.0, 422.0))
	sector.setResizingBehavior("end", "end")
	window.appendBody2D(sector)
	# Make an green annulus, pegged to the top of the window.
	annulus = jr.makeAnnulus(24.0, 48.0)
	annulus.setColor((0.0, 1.0, 0.0, 0.9))
	annulus.setPosition((160.0, 422.0))
	annulus.setResizingBehavior("start", "end")
	window.appendBody2D(annulus)
	# Make a cyan rectangle, rotated pi / 6 = 30 degrees counterclockwise.
	rectangle = jr.makeRectangle(64.0, 32.0)
	rectangle.setColor((0.0, 1.0, 1.0, 0.9))
	rectangle.setPosition((64.0, 256.0))
	rectangle.rotate(math.pi / 6.0)
	window.appendBody2D(rectangle)
	# Make a blue rounded rectangle.
	roundedRectangle = jr.makeRoundedRectangle(64.0, 96.0, 8.0)
	roundedRectangle.setColor((0.0, 0.0, 1.0, 0.9))
	roundedRectangle.setPosition((160.0, 90.0))
	window.appendBody2D(roundedRectangle)
	# Make a magenta polygon, pegged to the right side of the window.
	vertices = ((41.0, 5.0), (20.0, 50.0), (-70.0, 10.0), (-10.0, -60.0), (30.0, -30.0))
	polygon = jr.makeConvexPolygon(vertices)
	polygon.setColor((1.0, 0.0, 1.0, 0.9))
	polygon.setPosition((352.0, 90.0))
	polygon.setResizingBehavior("end", "start")
	window.appendBody2D(polygon)
	# Make some gray text.
	text = jr.makeText("Bopagopa", "/Library/Fonts/Silom.ttf", 18)
	text.setColor((0.5, 0.5, 0.5, 1.0))
	text.setPosition((256.0, 256.0))
	window.appendBody2D(text)
	# All Bopagopa programs end by running the user interface.
	jr.beginUserInterface()
