# 2010 October 3 by Joshua R. Davis

"""
This tutorial demonstrates how to join solids into a group that acts as a single solid. The idea is simple: Instead of attaching an object to the window, you attach it to the group; then you attach the group to the window. In this tutorial, the sphere, cone, and cylinder are joined into a single solid; try dragging on any of them, to see how they stick together. This tutorial also shows how to respond to mouse clicks and drags on solids. As in the earlier user interface tutorials, you write a callback function for each kind of user event, and then register that callback with the window. See the Window documentation for a complete listing of available event handlers.
"""

import bopagopa.bopagopajr as jr

def handleSolidClick(xy, name, xyz):
	"""If the shift key was down, then moves the light so that it is 1.0 unit above the point where the click happened. Otherwise behaves just like the ordinary Bopagopa Jr. 3D click handler."""
	window = jr.getWindow()
	if window.shiftKeyWasDown():
		light = window.getLights()[0]
		light.setPosition(jr.vectorSum(xyz, (0.0, 0.0, 1.0)))
		window.needsRedrawing()
	else:
		window.defaultClickHandler3D(xy, name, xyz)

def handleSolidEndDrag(xyStarting, xyPrevious, xyFinal, name, xyzStarting):
	"""Prints out information about the drag."""
	print "You dragged solid " + str(name) + " starting at world coordinates " + str(xyzStarting) + "."

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window. We also register interface handlers.
	window = jr.WindowJr()
	window.setClickHandler3D(handleSolidClick)
	window.setEndDragHandler3D(handleSolidEndDrag)
	# Make some lights.
	light = jr.Light()
	window.setLights((light,))
	# Make some solids.
	box = jr.makeBox(10.0, 10.0, 1.0)
	box.setColor((0.0, 1.0, 0.0))
	box.setPosition((0.0, 0.0, -1.0))
	window.appendBody3D(box)
	capsule = jr.makeCapsule(1.0, 0.5)
	capsule.setColor((1.0, 0.0, 1.0))
	capsule.setPosition((0.0, 2.0, 1.0))
	window.appendBody3D(capsule)
	# Make some solids joined together into a group.
	cylinder = jr.makeCylinder(1.0, 0.5)
	cylinder.setColor((0.0, 0.0, 1.0))
	sphere = jr.makeSphere(1.0)
	sphere.setColor((1.0, 1.0, 0.0))
	sphere.setPosition((0.0, 0.0, 1.5))
	cone = jr.makeCone(1.0, 0.5)
	cone.setColor((1.0, 0.5, 0.0))
	cone.setPosition((0.0, 0.0, 2.5))
	group = jr.Group3D([cylinder, cone, sphere])
	window.appendBody3D(group)
	# All Bopagopa programs end by running the user interface.
	jr.beginUserInterface()
